==> jc-1.4.0.tar.gz: java/awt/event/InvocationEvent.h <==
// public class java.awt.event.InvocationEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class c2a9d24fb0e127f2 java_awt_event_InvocationEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_InvocationEvent_H_
#define _JC_java_awt_event_InvocationEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_Runnable$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_InvocationEvent$sub_refs	_jc_java_awt_event_InvocationEvent$sub_refs;
typedef struct _jc_java_awt_event_InvocationEvent$sub_nonrefs	_jc_java_awt_event_InvocationEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_InvocationEvent$refs	_jc_java_awt_event_InvocationEvent$refs;
typedef struct _jc_java_awt_event_InvocationEvent$nonrefs	_jc_java_awt_event_InvocationEvent$nonrefs;
typedef struct _jc_java_awt_event_InvocationEvent$object	_jc_java_awt_event_InvocationEvent$object;

typedef struct _jc_java_awt_event_InvocationEvent$fields_struct	_jc_java_awt_event_InvocationEvent$fields_struct;
typedef const struct _jc_java_awt_event_InvocationEvent$vmethods	_jc_java_awt_event_InvocationEvent$vmethods;
typedef const struct _jc_java_awt_event_InvocationEvent$vtable	_jc_java_awt_event_InvocationEvent$vtable;
typedef const struct _jc_java_awt_event_InvocationEvent$vtype	_jc_java_awt_event_InvocationEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_InvocationEvent$fields_struct {
	jlong	serialVersionUID;
	jint	INVOCATION__5fDEFAULT;
	jint	INVOCATION__5fFIRST;
	jint	INVOCATION__5fLAST;
};
extern _jc_java_awt_event_InvocationEvent$fields_struct _jc_java_awt_event_InvocationEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_InvocationEvent$method$_init$92979c6ebccca5db(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_object *, struct _jc_java_lang_Object$object *, jboolean);
extern void _jc_java_awt_event_InvocationEvent$method$_init$76d53caafc9a95a5(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);
extern void _jc_java_awt_event_InvocationEvent$method$_init$fbd4312758145116(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, jboolean);

// Virtual methods
extern void _jc_java_awt_event_InvocationEvent$method$dispatch$93f2f44dbc7127b9(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);
extern struct _jc_java_lang_Exception$object *_jc_java_awt_event_InvocationEvent$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);
extern jlong _jc_java_awt_event_InvocationEvent$method$getWhen$3d8a46a7284dd8d9(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_InvocationEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);
extern void _jc_java_awt_event_InvocationEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$dispatch$93f2f44dbc7127b9;
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$getWhen$3d8a46a7284dd8d9;
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_event_InvocationEvent$vmethods {
	void	(*dispatch$93f2f44dbc7127b9)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);
	jlong	(*getWhen$3d8a46a7284dd8d9)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *);
};

// Vtable
struct _jc_java_awt_event_InvocationEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_InvocationEvent$vmethods	java_awt_event_InvocationEvent;
};

// Vtype
struct _jc_java_awt_event_InvocationEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_InvocationEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_InvocationEvent$sub_refs {
	struct _jc_object	*runnable;
	struct _jc_java_lang_Object$object	*notifier;
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_java_awt_event_InvocationEvent$refs {
    _jc_java_awt_event_InvocationEvent$sub_refs	java_awt_event_InvocationEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_InvocationEvent$sub_nonrefs {
	jboolean	catchExceptions;
	jlong	when;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_InvocationEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_InvocationEvent$sub_nonrefs	java_awt_event_InvocationEvent;
};

// Object instance structure
struct _jc_java_awt_event_InvocationEvent$object {
	_jc_java_awt_event_InvocationEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_InvocationEvent$vtype	*vtype;
	_jc_java_awt_event_InvocationEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_InvocationEvent$vtype _jc_java_awt_event_InvocationEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_InvocationEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_InvocationEvent$class_object;

#endif	/* _JC_java_awt_event_InvocationEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/InvocationEvent.h <==
// public class java.awt.event.InvocationEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class c2a9d24fb0e127f2 java_awt_event_InvocationEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_AWTEvent

#include "java/awt/AWTEvent.h"

#ifndef _JC_java_awt_event_InvocationEvent_H_
#define _JC_java_awt_event_InvocationEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_Runnable$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_InvocationEvent$sub_refs	_jc_java_awt_event_InvocationEvent$sub_refs;
typedef struct _jc_java_awt_event_InvocationEvent$sub_nonrefs	_jc_java_awt_event_InvocationEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_InvocationEvent$refs	_jc_java_awt_event_InvocationEvent$refs;
typedef struct _jc_java_awt_event_InvocationEvent$nonrefs	_jc_java_awt_event_InvocationEvent$nonrefs;
typedef struct _jc_java_awt_event_InvocationEvent$object	_jc_java_awt_event_InvocationEvent$object;

typedef struct _jc_java_awt_event_InvocationEvent$fields_struct	_jc_java_awt_event_InvocationEvent$fields_struct;
typedef const struct _jc_java_awt_event_InvocationEvent$vmethods	_jc_java_awt_event_InvocationEvent$vmethods;
typedef const struct _jc_java_awt_event_InvocationEvent$vtable	_jc_java_awt_event_InvocationEvent$vtable;
typedef const struct _jc_java_awt_event_InvocationEvent$vtype	_jc_java_awt_event_InvocationEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_InvocationEvent$fields_struct {
	jlong	serialVersionUID;
	jint	INVOCATION__5fDEFAULT;
	jint	INVOCATION__5fFIRST;
	jint	INVOCATION__5fLAST;
};
extern _jc_java_awt_event_InvocationEvent$fields_struct _jc_java_awt_event_InvocationEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_InvocationEvent$method$_init$92979c6ebccca5db(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *, struct _jc_java_lang_Object$object *, jint, struct _jc_object *, struct _jc_java_lang_Object$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_InvocationEvent$method$_init$76d53caafc9a95a5(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_InvocationEvent$method$_init$fbd4312758145116(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *, struct _jc_java_lang_Object$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_InvocationEvent$method$dispatch$93f2f44dbc7127b9(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Exception$object *_jc_java_awt_event_InvocationEvent$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_awt_event_InvocationEvent$method$getWhen$3d8a46a7284dd8d9(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_InvocationEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_InvocationEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$dispatch$93f2f44dbc7127b9;
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$getWhen$3d8a46a7284dd8d9;
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_event_InvocationEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_event_InvocationEvent$vmethods {
	void	(*dispatch$93f2f44dbc7127b9)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;
	jlong	(*getWhen$3d8a46a7284dd8d9)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_event_InvocationEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_InvocationEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_InvocationEvent$vmethods	java_awt_event_InvocationEvent;
};

// Vtype
struct _jc_java_awt_event_InvocationEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_InvocationEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_InvocationEvent$sub_refs {
	struct _jc_object	*runnable;
	struct _jc_java_lang_Object$object	*notifier;
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_java_awt_event_InvocationEvent$refs {
    _jc_java_awt_event_InvocationEvent$sub_refs	java_awt_event_InvocationEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_InvocationEvent$sub_nonrefs {
	jboolean	catchExceptions;
	jlong	when;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_InvocationEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_InvocationEvent$sub_nonrefs	java_awt_event_InvocationEvent;
};

// Object instance structure
struct _jc_java_awt_event_InvocationEvent$object {
	_jc_java_awt_event_InvocationEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_InvocationEvent$vtype	*vtype;
	_jc_java_awt_event_InvocationEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_InvocationEvent$vtype _jc_java_awt_event_InvocationEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_InvocationEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_InvocationEvent$class_object;

#endif	/* _JC_java_awt_event_InvocationEvent_H_ */
